# Go API client for metalv1

# Introduction
Equinix Metal provides a RESTful HTTP API which can be reached at <https://api.equinix.com/metal/v1>. This document describes the API and how to use it.

The API allows you to programmatically interact with all
of your Equinix Metal resources, including devices, networks, addresses, organizations,
projects, and your user account. Every feature of the Equinix Metal web interface is accessible through the API.

The API docs are generated from the Equinix Metal OpenAPI specification and are officially hosted at <https://metal.equinix.com/developers/api>.

# Common Parameters

The Equinix Metal API uses a few methods to minimize network traffic and improve throughput. These parameters are not used in all API calls, but are used often enough to warrant their own section. Look for these parameters in the documentation for the API calls that support them.

## Pagination

Pagination is used to limit the number of results returned in a single request. The API will return a maximum of 100 results per page. To retrieve additional results, you can use the `page` and `per_page` query parameters.

The `page` parameter is used to specify the page number. The first page is `1`. The `per_page` parameter is used to specify the number of results per page. The maximum number of results differs by resource type.

## Sorting

Where offered, the API allows you to sort results by a specific field. To sort results use the `sort_by` query parameter with the root level field name as the value. The `sort_direction` parameter is used to specify the sort direction, either either `asc` (ascending) or `desc` (descending).

## Filtering

Filtering is used to limit the results returned in a single request. The API supports filtering by certain fields in the response. To filter results, you can use the field as a query parameter.

For example, to filter the IP list to only return public IPv4 addresses, you can filter by the `type` field, as in the following request:

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/projects/id/ips?type=public_ipv4
```

Only IP addresses with the `type` field set to `public_ipv4` will be returned.

## Searching

Searching is used to find matching resources using multiple field comparissons. The API supports searching in resources that define this behavior. Currently the search parameter is only available on devices, ssh_keys, api_keys and memberships endpoints.

To search resources you can use the `search` query parameter.

## Include and Exclude

For resources that contain references to other resources, sucha as a Device that refers to the Project it resides in, the Equinix Metal API will returns `href` values (API links) to the associated resource.

```json
{
  ...
  \"project\": {
    \"href\": \"/metal/v1/projects/f3f131c8-f302-49ef-8c44-9405022dc6dd\"
  }
}
```

If you're going need the project details, you can avoid a second API request.  Specify the contained `href` resources and collections that you'd like to have included in the response using the `include` query parameter.

For example:

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=projects
```

The `include` parameter is generally accepted in `GET`, `POST`, `PUT`, and `PATCH` requests where `href` resources are presented.

To have multiple resources include, use a comma-separated list (e.g. `?include=emails,projects,memberships`).

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=emails,projects,memberships
```

You may also include nested associations up to three levels deep using dot notation (`?include=memberships.projects`):

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=memberships.projects
```

To exclude resources, and optimize response delivery, use the `exclude` query parameter. The `exclude` parameter is generally accepted in `GET`, `POST`, `PUT`, and `PATCH` requests for fields with nested object responses. When excluded, these fields will be replaced with an object that contains only an `href` field.


## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 1.0.0
- Package version: 0.42.0
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```sh
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```go
import metalv1 "github.com/equinix/equinix-sdk-go/services/metalv1"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```go
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `metalv1.ContextServerIndex` of type `int`.

```go
ctx := context.WithValue(context.Background(), metalv1.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `metalv1.ContextServerVariables` of type `map[string]string`.

```go
ctx := context.WithValue(context.Background(), metalv1.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `metalv1.ContextOperationServerIndices` and `metalv1.ContextOperationServerVariables` context maps.

```go
ctx := context.WithValue(context.Background(), metalv1.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), metalv1.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *https://api.equinix.com/metal/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthenticationApi* | [**CreateAPIKey**](docs/AuthenticationApi.md#createapikey) | **Post** /user/api-keys | Create an API key
*AuthenticationApi* | [**CreateProjectAPIKey**](docs/AuthenticationApi.md#createprojectapikey) | **Post** /projects/{id}/api-keys | Create an API key for a project.
*AuthenticationApi* | [**DeleteAPIKey**](docs/AuthenticationApi.md#deleteapikey) | **Delete** /api-keys/{id} | Delete the API key
*AuthenticationApi* | [**DeleteUserAPIKey**](docs/AuthenticationApi.md#deleteuserapikey) | **Delete** /user/api-keys/{id} | Delete the API key
*AuthenticationApi* | [**FindAPIKeys**](docs/AuthenticationApi.md#findapikeys) | **Get** /user/api-keys | Retrieve all user API keys
*AuthenticationApi* | [**FindProjectAPIKeys**](docs/AuthenticationApi.md#findprojectapikeys) | **Get** /projects/{id}/api-keys | Retrieve all API keys for the project.
*BGPApi* | [**DeleteBgpSession**](docs/BGPApi.md#deletebgpsession) | **Delete** /bgp/sessions/{id} | Delete the BGP session
*BGPApi* | [**FindBgpConfigByProject**](docs/BGPApi.md#findbgpconfigbyproject) | **Get** /projects/{id}/bgp-config | Retrieve a bgp config
*BGPApi* | [**FindBgpSessionById**](docs/BGPApi.md#findbgpsessionbyid) | **Get** /bgp/sessions/{id} | Retrieve a BGP session
*BGPApi* | [**FindGlobalBgpRanges**](docs/BGPApi.md#findglobalbgpranges) | **Get** /projects/{id}/global-bgp-ranges | Retrieve all global bgp ranges
*BGPApi* | [**FindProjectBgpSessions**](docs/BGPApi.md#findprojectbgpsessions) | **Get** /projects/{id}/bgp/sessions | Retrieve all BGP sessions for project
*BGPApi* | [**RequestBgpConfig**](docs/BGPApi.md#requestbgpconfig) | **Post** /projects/{id}/bgp-configs | Requesting bgp config
*BGPApi* | [**UpdateBgpSession**](docs/BGPApi.md#updatebgpsession) | **Put** /bgp/sessions/{id} | Update the BGP session
*BatchesApi* | [**CreateDeviceBatch**](docs/BatchesApi.md#createdevicebatch) | **Post** /projects/{id}/devices/batch | Create a devices batch
*BatchesApi* | [**DeleteBatch**](docs/BatchesApi.md#deletebatch) | **Delete** /batches/{id} | Delete the Batch
*BatchesApi* | [**FindBatchById**](docs/BatchesApi.md#findbatchbyid) | **Get** /batches/{id} | Retrieve a Batch
*BatchesApi* | [**FindBatchesByProject**](docs/BatchesApi.md#findbatchesbyproject) | **Get** /projects/{id}/batches | Retrieve all batches by project
*CapacityApi* | [**CheckCapacityForFacility**](docs/CapacityApi.md#checkcapacityforfacility) | **Post** /capacity | Check capacity
*CapacityApi* | [**CheckCapacityForMetro**](docs/CapacityApi.md#checkcapacityformetro) | **Post** /capacity/metros | Check capacity for a metro
*CapacityApi* | [**FindCapacityForFacility**](docs/CapacityApi.md#findcapacityforfacility) | **Get** /capacity | View capacity
*CapacityApi* | [**FindCapacityForMetro**](docs/CapacityApi.md#findcapacityformetro) | **Get** /capacity/metros | View capacity for metros
*CapacityApi* | [**FindOrganizationCapacityPerFacility**](docs/CapacityApi.md#findorganizationcapacityperfacility) | **Get** /organizations/{id}/capacity | View available hardware plans per Facility for given organization
*CapacityApi* | [**FindOrganizationCapacityPerMetro**](docs/CapacityApi.md#findorganizationcapacitypermetro) | **Get** /organizations/{id}/capacity/metros | View available hardware plans per Metro for given organization
*ConsoleLogDetailsApi* | [**CaptureScreenshot**](docs/ConsoleLogDetailsApi.md#capturescreenshot) | **Get** /devices/{id}/diagnostics/screenshot | 
*DevicesApi* | [**CreateBgpSession**](docs/DevicesApi.md#createbgpsession) | **Post** /devices/{id}/bgp/sessions | Create a BGP session
*DevicesApi* | [**CreateDevice**](docs/DevicesApi.md#createdevice) | **Post** /projects/{id}/devices | Create a device
*DevicesApi* | [**CreateIPAssignment**](docs/DevicesApi.md#createipassignment) | **Post** /devices/{id}/ips | Create an ip assignment
*DevicesApi* | [**DeleteDevice**](docs/DevicesApi.md#deletedevice) | **Delete** /devices/{id} | Delete the device
*DevicesApi* | [**FindBgpSessions**](docs/DevicesApi.md#findbgpsessions) | **Get** /devices/{id}/bgp/sessions | Retrieve all BGP sessions
*DevicesApi* | [**FindDeviceById**](docs/DevicesApi.md#finddevicebyid) | **Get** /devices/{id} | Retrieve a device
*DevicesApi* | [**FindDeviceCustomdata**](docs/DevicesApi.md#finddevicecustomdata) | **Get** /devices/{id}/customdata | Retrieve the custom metadata of an instance
*DevicesApi* | [**FindDeviceMetadataByID**](docs/DevicesApi.md#finddevicemetadatabyid) | **Get** /devices/{id}/metadata | Retrieve metadata
*DevicesApi* | [**FindDeviceUserdataByID**](docs/DevicesApi.md#finddeviceuserdatabyid) | **Get** /devices/{id}/userdata | Retrieve userdata
*DevicesApi* | [**FindIPAssignmentCustomdata**](docs/DevicesApi.md#findipassignmentcustomdata) | **Get** /devices/{instance_id}/ips/{id}/customdata | Retrieve the custom metadata of an IP Assignment
*DevicesApi* | [**FindIPAssignments**](docs/DevicesApi.md#findipassignments) | **Get** /devices/{id}/ips | Retrieve all ip assignments
*DevicesApi* | [**FindInstanceBandwidth**](docs/DevicesApi.md#findinstancebandwidth) | **Get** /devices/{id}/bandwidth | Retrieve an instance bandwidth
*DevicesApi* | [**FindOrganizationDevices**](docs/DevicesApi.md#findorganizationdevices) | **Get** /organizations/{id}/devices | Retrieve all devices of an organization
*DevicesApi* | [**FindProjectDevices**](docs/DevicesApi.md#findprojectdevices) | **Get** /projects/{id}/devices | Retrieve all devices of a project
*DevicesApi* | [**FindTraffic**](docs/DevicesApi.md#findtraffic) | **Get** /devices/{id}/traffic | Retrieve device traffic
*DevicesApi* | [**GetBgpNeighborData**](docs/DevicesApi.md#getbgpneighbordata) | **Get** /devices/{id}/bgp/neighbors | Retrieve BGP neighbor data for this device
*DevicesApi* | [**GetDeviceFirmwareSets**](docs/DevicesApi.md#getdevicefirmwaresets) | **Get** /devices/{id}/firmware-sets | Get Device&#39;s associated Firmware Set
*DevicesApi* | [**GetDeviceHealthRollup**](docs/DevicesApi.md#getdevicehealthrollup) | **Get** /devices/{id}/diagnostics/health/rollup | Get Device&#39;s Health Status
*DevicesApi* | [**PerformAction**](docs/DevicesApi.md#performaction) | **Post** /devices/{id}/actions | Perform an action
*DevicesApi* | [**UpdateDevice**](docs/DevicesApi.md#updatedevice) | **Put** /devices/{id} | Update the device
*EmailsApi* | [**CreateEmail**](docs/EmailsApi.md#createemail) | **Post** /emails | Create an email
*EmailsApi* | [**DeleteEmail**](docs/EmailsApi.md#deleteemail) | **Delete** /emails/{id} | Delete the email
*EmailsApi* | [**FindEmailById**](docs/EmailsApi.md#findemailbyid) | **Get** /emails/{id} | Retrieve an email
*EmailsApi* | [**UpdateEmail**](docs/EmailsApi.md#updateemail) | **Put** /emails/{id} | Update the email
*EventsApi* | [**FindDeviceEvents**](docs/EventsApi.md#finddeviceevents) | **Get** /devices/{id}/events | Retrieve device&#39;s events
*EventsApi* | [**FindEventById**](docs/EventsApi.md#findeventbyid) | **Get** /events/{id} | Retrieve an event
*EventsApi* | [**FindEvents**](docs/EventsApi.md#findevents) | **Get** /events | Retrieve current user&#39;s events
*EventsApi* | [**FindInterconnectionEvents**](docs/EventsApi.md#findinterconnectionevents) | **Get** /connections/{connection_id}/events | Retrieve interconnection events
*EventsApi* | [**FindInterconnectionPortEvents**](docs/EventsApi.md#findinterconnectionportevents) | **Get** /connections/{connection_id}/ports/{id}/events | Retrieve interconnection port events
*EventsApi* | [**FindOrganizationEvents**](docs/EventsApi.md#findorganizationevents) | **Get** /organizations/{id}/events | Retrieve organization&#39;s events
*EventsApi* | [**FindProjectEvents**](docs/EventsApi.md#findprojectevents) | **Get** /projects/{id}/events | Retrieve project&#39;s events
*EventsApi* | [**FindVirtualCircuitEvents**](docs/EventsApi.md#findvirtualcircuitevents) | **Get** /virtual-circuits/{id}/events | Retrieve virtual circuit events
*EventsApi* | [**FindVrfRouteEvents**](docs/EventsApi.md#findvrfrouteevents) | **Get** /routes/{id}/events | Retrieve VRF route events
*FacilitiesApi* | [**FindFacilities**](docs/FacilitiesApi.md#findfacilities) | **Get** /facilities | Retrieve all facilities
*FacilitiesApi* | [**FindFacilitiesByOrganization**](docs/FacilitiesApi.md#findfacilitiesbyorganization) | **Get** /organizations/{id}/facilities | Retrieve all facilities visible by the organization
*FacilitiesApi* | [**FindFacilitiesByProject**](docs/FacilitiesApi.md#findfacilitiesbyproject) | **Get** /projects/{id}/facilities | Retrieve all facilities visible by the project
*FirmwareSetsApi* | [**GetOrganizationFirmwareSets**](docs/FirmwareSetsApi.md#getorganizationfirmwaresets) | **Get** /organizations/{id}/firmware-sets | Get Organization&#39;s Firmware Sets
*FirmwareSetsApi* | [**GetProjectFirmwareSets**](docs/FirmwareSetsApi.md#getprojectfirmwaresets) | **Get** /projects/{id}/firmware-sets | Get Project&#39;s Firmware Sets
*HardwareReservationsApi* | [**ActivateHardwareReservation**](docs/HardwareReservationsApi.md#activatehardwarereservation) | **Post** /hardware-reservations/{id}/activate | Activate a spare hardware reservation
*HardwareReservationsApi* | [**FindHardwareReservationById**](docs/HardwareReservationsApi.md#findhardwarereservationbyid) | **Get** /hardware-reservations/{id} | Retrieve a hardware reservation
*HardwareReservationsApi* | [**FindProjectHardwareReservations**](docs/HardwareReservationsApi.md#findprojecthardwarereservations) | **Get** /projects/{id}/hardware-reservations | Retrieve all hardware reservations for a given project
*HardwareReservationsApi* | [**MoveHardwareReservation**](docs/HardwareReservationsApi.md#movehardwarereservation) | **Post** /hardware-reservations/{id}/move | Move a hardware reservation
*IPAddressesApi* | [**DeleteIPAddress**](docs/IPAddressesApi.md#deleteipaddress) | **Delete** /ips/{id} | Unassign an ip address
*IPAddressesApi* | [**FindIPAddressById**](docs/IPAddressesApi.md#findipaddressbyid) | **Get** /ips/{id} | Retrieve an ip address
*IPAddressesApi* | [**FindIPAddressCustomdata**](docs/IPAddressesApi.md#findipaddresscustomdata) | **Get** /ips/{id}/customdata | Retrieve the custom metadata of an IP Reservation or IP Assignment
*IPAddressesApi* | [**FindIPAvailabilities**](docs/IPAddressesApi.md#findipavailabilities) | **Get** /ips/{id}/available | Retrieve all available subnets of a particular reservation
*IPAddressesApi* | [**FindIPReservations**](docs/IPAddressesApi.md#findipreservations) | **Get** /projects/{id}/ips | Retrieve all ip reservations
*IPAddressesApi* | [**RequestIPReservation**](docs/IPAddressesApi.md#requestipreservation) | **Post** /projects/{id}/ips | Requesting IP reservations
*IPAddressesApi* | [**UpdateIPAddress**](docs/IPAddressesApi.md#updateipaddress) | **Patch** /ips/{id} | Update an ip address
*IncidentsApi* | [**FindIncidents**](docs/IncidentsApi.md#findincidents) | **Get** /incidents | Retrieve the number of incidents
*InterconnectionsApi* | [**CreateInterconnectionPortVirtualCircuit**](docs/InterconnectionsApi.md#createinterconnectionportvirtualcircuit) | **Post** /connections/{connection_id}/ports/{port_id}/virtual-circuits | Create a new Virtual Circuit
*InterconnectionsApi* | [**CreateOrganizationInterconnection**](docs/InterconnectionsApi.md#createorganizationinterconnection) | **Post** /organizations/{organization_id}/connections | Request a new interconnection for the organization
*InterconnectionsApi* | [**CreateProjectInterconnection**](docs/InterconnectionsApi.md#createprojectinterconnection) | **Post** /projects/{project_id}/connections | Request a new interconnection for the project&#39;s organization
*InterconnectionsApi* | [**DeleteInterconnection**](docs/InterconnectionsApi.md#deleteinterconnection) | **Delete** /connections/{connection_id} | Delete interconnection
*InterconnectionsApi* | [**DeleteVirtualCircuit**](docs/InterconnectionsApi.md#deletevirtualcircuit) | **Delete** /virtual-circuits/{id} | Delete a virtual circuit
*InterconnectionsApi* | [**GetInterconnection**](docs/InterconnectionsApi.md#getinterconnection) | **Get** /connections/{connection_id} | Get interconnection
*InterconnectionsApi* | [**GetInterconnectionMetros**](docs/InterconnectionsApi.md#getinterconnectionmetros) | **Get** /connections/metros | Get connectivity to network provider by metro
*InterconnectionsApi* | [**GetInterconnectionPort**](docs/InterconnectionsApi.md#getinterconnectionport) | **Get** /connections/{connection_id}/ports/{id} | Get a interconnection port
*InterconnectionsApi* | [**GetInterconnectionPricing**](docs/InterconnectionsApi.md#getinterconnectionpricing) | **Get** /connections/prices | Get Interconnection Pricing
*InterconnectionsApi* | [**GetVirtualCircuit**](docs/InterconnectionsApi.md#getvirtualcircuit) | **Get** /virtual-circuits/{id} | Get a virtual circuit
*InterconnectionsApi* | [**ListInterconnectionPortVirtualCircuits**](docs/InterconnectionsApi.md#listinterconnectionportvirtualcircuits) | **Get** /connections/{connection_id}/ports/{port_id}/virtual-circuits | List a interconnection port&#39;s virtual circuits
*InterconnectionsApi* | [**ListInterconnectionPorts**](docs/InterconnectionsApi.md#listinterconnectionports) | **Get** /connections/{connection_id}/ports | List a interconnection&#39;s ports
*InterconnectionsApi* | [**ListInterconnectionVirtualCircuits**](docs/InterconnectionsApi.md#listinterconnectionvirtualcircuits) | **Get** /connections/{connection_id}/virtual-circuits | List a interconnection&#39;s virtual circuits
*InterconnectionsApi* | [**OrganizationListInterconnections**](docs/InterconnectionsApi.md#organizationlistinterconnections) | **Get** /organizations/{organization_id}/connections | List organization connections
*InterconnectionsApi* | [**ProjectListInterconnections**](docs/InterconnectionsApi.md#projectlistinterconnections) | **Get** /projects/{project_id}/connections | List project connections
*InterconnectionsApi* | [**UpdateInterconnection**](docs/InterconnectionsApi.md#updateinterconnection) | **Put** /connections/{connection_id} | Update interconnection
*InterconnectionsApi* | [**UpdateVirtualCircuit**](docs/InterconnectionsApi.md#updatevirtualcircuit) | **Put** /virtual-circuits/{id} | Update a virtual circuit
*InvitationsApi* | [**AcceptInvitation**](docs/InvitationsApi.md#acceptinvitation) | **Put** /invitations/{id} | Accept an invitation
*InvitationsApi* | [**DeclineInvitation**](docs/InvitationsApi.md#declineinvitation) | **Delete** /invitations/{id} | Decline an invitation
*InvitationsApi* | [**FindInvitationById**](docs/InvitationsApi.md#findinvitationbyid) | **Get** /invitations/{id} | View an invitation
*InvoicesApi* | [**FindOrganizationInvoices**](docs/InvoicesApi.md#findorganizationinvoices) | **Get** /organizations/{id}/invoices | Retrieve all invoices for an organization
*InvoicesApi* | [**GetInvoiceById**](docs/InvoicesApi.md#getinvoicebyid) | **Get** /invoices/{id} | Retrieve an invoice
*LicensesApi* | [**CreateLicense**](docs/LicensesApi.md#createlicense) | **Post** /projects/{id}/licenses | Create a License
*LicensesApi* | [**DeleteLicense**](docs/LicensesApi.md#deletelicense) | **Delete** /licenses/{id} | Delete the license
*LicensesApi* | [**FindLicenseById**](docs/LicensesApi.md#findlicensebyid) | **Get** /licenses/{id} | Retrieve a license
*LicensesApi* | [**FindProjectLicenses**](docs/LicensesApi.md#findprojectlicenses) | **Get** /projects/{id}/licenses | Retrieve all licenses
*LicensesApi* | [**UpdateLicense**](docs/LicensesApi.md#updatelicense) | **Put** /licenses/{id} | Update the license
*MembershipsApi* | [**DeleteMembership**](docs/MembershipsApi.md#deletemembership) | **Delete** /memberships/{id} | Delete the membership
*MembershipsApi* | [**FindMembershipById**](docs/MembershipsApi.md#findmembershipbyid) | **Get** /memberships/{id} | Retrieve a membership
*MembershipsApi* | [**UpdateMembership**](docs/MembershipsApi.md#updatemembership) | **Put** /memberships/{id} | Update the membership
*MetalGatewaysApi* | [**CreateMetalGateway**](docs/MetalGatewaysApi.md#createmetalgateway) | **Post** /projects/{project_id}/metal-gateways | Create a metal gateway
*MetalGatewaysApi* | [**CreateMetalGatewayElasticIp**](docs/MetalGatewaysApi.md#createmetalgatewayelasticip) | **Post** /metal-gateways/{id}/ips | Create a Metal Gateway Elastic IP
*MetalGatewaysApi* | [**DeleteMetalGateway**](docs/MetalGatewaysApi.md#deletemetalgateway) | **Delete** /metal-gateways/{id} | Deletes the metal gateway
*MetalGatewaysApi* | [**FindMetalGatewayById**](docs/MetalGatewaysApi.md#findmetalgatewaybyid) | **Get** /metal-gateways/{id} | Returns the metal gateway
*MetalGatewaysApi* | [**FindMetalGatewaysByProject**](docs/MetalGatewaysApi.md#findmetalgatewaysbyproject) | **Get** /projects/{project_id}/metal-gateways | Returns all metal gateways for a project
*MetalGatewaysApi* | [**GetMetalGatewayElasticIps**](docs/MetalGatewaysApi.md#getmetalgatewayelasticips) | **Get** /metal-gateways/{id}/ips | List Metal Gateway Elastic IPs
*MetrosApi* | [**FindMetros**](docs/MetrosApi.md#findmetros) | **Get** /locations/metros | Retrieve all metros
*MetrosApi* | [**GetMetro**](docs/MetrosApi.md#getmetro) | **Get** /locations/metros/{id} | Retrieve a specific Metro&#39;s details
*OTPsApi* | [**FindEnsureOtp**](docs/OTPsApi.md#findensureotp) | **Post** /user/otp/verify/{otp} | Verify user by providing an OTP
*OTPsApi* | [**FindRecoveryCodes**](docs/OTPsApi.md#findrecoverycodes) | **Get** /user/otp/recovery-codes | Retrieve my recovery codes
*OTPsApi* | [**ReceiveCodes**](docs/OTPsApi.md#receivecodes) | **Post** /user/otp/sms/receive | Receive an OTP per sms
*OTPsApi* | [**RegenerateCodes**](docs/OTPsApi.md#regeneratecodes) | **Post** /user/otp/recovery-codes | Generate new recovery codes
*OTPsApi* | [**SeedApp**](docs/OTPsApi.md#seedapp) | **Post** /user/otp/app/receive | Issue OTP seeds
*OperatingSystemsApi* | [**FindOperatingSystemVersion**](docs/OperatingSystemsApi.md#findoperatingsystemversion) | **Get** /operating-system-versions | Retrieve all operating system versions
*OperatingSystemsApi* | [**FindOperatingSystems**](docs/OperatingSystemsApi.md#findoperatingsystems) | **Get** /operating-systems | Retrieve all operating systems
*OrganizationsApi* | [**CreateOrganization**](docs/OrganizationsApi.md#createorganization) | **Post** /organizations | Create an organization
*OrganizationsApi* | [**CreateOrganizationInvitation**](docs/OrganizationsApi.md#createorganizationinvitation) | **Post** /organizations/{id}/invitations | Create an invitation for an organization
*OrganizationsApi* | [**CreateOrganizationProject**](docs/OrganizationsApi.md#createorganizationproject) | **Post** /organizations/{id}/projects | Create a project for the organization
*OrganizationsApi* | [**CreatePaymentMethod**](docs/OrganizationsApi.md#createpaymentmethod) | **Post** /organizations/{id}/payment-methods | Create a payment method for the given organization
*OrganizationsApi* | [**DeleteOrganization**](docs/OrganizationsApi.md#deleteorganization) | **Delete** /organizations/{id} | Delete the organization
*OrganizationsApi* | [**FindOperatingSystemsByOrganization**](docs/OrganizationsApi.md#findoperatingsystemsbyorganization) | **Get** /organizations/{id}/operating-systems | Retrieve all operating systems visible by the organization
*OrganizationsApi* | [**FindOrganizationById**](docs/OrganizationsApi.md#findorganizationbyid) | **Get** /organizations/{id} | Retrieve an organization&#39;s details
*OrganizationsApi* | [**FindOrganizationCustomdata**](docs/OrganizationsApi.md#findorganizationcustomdata) | **Get** /organizations/{id}/customdata | Retrieve the custom metadata of an organization
*OrganizationsApi* | [**FindOrganizationInvitations**](docs/OrganizationsApi.md#findorganizationinvitations) | **Get** /organizations/{id}/invitations | Retrieve organization invitations
*OrganizationsApi* | [**FindOrganizationPaymentMethods**](docs/OrganizationsApi.md#findorganizationpaymentmethods) | **Get** /organizations/{id}/payment-methods | Retrieve all payment methods of an organization
*OrganizationsApi* | [**FindOrganizationProjects**](docs/OrganizationsApi.md#findorganizationprojects) | **Get** /organizations/{id}/projects | Retrieve all projects of an organization
*OrganizationsApi* | [**FindOrganizationTransfers**](docs/OrganizationsApi.md#findorganizationtransfers) | **Get** /organizations/{id}/transfers | Retrieve all project transfer requests from or to an organization
*OrganizationsApi* | [**FindOrganizations**](docs/OrganizationsApi.md#findorganizations) | **Get** /organizations | Retrieve all organizations
*OrganizationsApi* | [**FindPlansByOrganization**](docs/OrganizationsApi.md#findplansbyorganization) | **Get** /organizations/{id}/plans | Retrieve all plans visible by the organization
*OrganizationsApi* | [**UpdateOrganization**](docs/OrganizationsApi.md#updateorganization) | **Put** /organizations/{id} | Update the organization
*PasswordResetTokensApi* | [**CreatePasswordResetToken**](docs/PasswordResetTokensApi.md#createpasswordresettoken) | **Post** /reset-password | Create a password reset token
*PasswordResetTokensApi* | [**ResetPassword**](docs/PasswordResetTokensApi.md#resetpassword) | **Delete** /reset-password | Reset current user password
*PaymentMethodsApi* | [**DeletePaymentMethod**](docs/PaymentMethodsApi.md#deletepaymentmethod) | **Delete** /payment-methods/{id} | Delete the payment method
*PaymentMethodsApi* | [**FindPaymentMethodById**](docs/PaymentMethodsApi.md#findpaymentmethodbyid) | **Get** /payment-methods/{id} | Retrieve a payment method
*PaymentMethodsApi* | [**UpdatePaymentMethod**](docs/PaymentMethodsApi.md#updatepaymentmethod) | **Put** /payment-methods/{id} | Update the payment method
*PlansApi* | [**FindPlans**](docs/PlansApi.md#findplans) | **Get** /plans | Retrieve all plans
*PlansApi* | [**FindPlansByProject**](docs/PlansApi.md#findplansbyproject) | **Get** /projects/{id}/plans | Retrieve all plans visible by the project
*PortsApi* | [**AssignNativeVlan**](docs/PortsApi.md#assignnativevlan) | **Post** /ports/{id}/native-vlan | Assign a native VLAN
*PortsApi* | [**AssignPort**](docs/PortsApi.md#assignport) | **Post** /ports/{id}/assign | Assign a port to virtual network
*PortsApi* | [**BondPort**](docs/PortsApi.md#bondport) | **Post** /ports/{id}/bond | Enabling bonding
*PortsApi* | [**ConvertLayer2**](docs/PortsApi.md#convertlayer2) | **Post** /ports/{id}/convert/layer-2 | Convert to Layer 2
*PortsApi* | [**ConvertLayer3**](docs/PortsApi.md#convertlayer3) | **Post** /ports/{id}/convert/layer-3 | Convert to Layer 3
*PortsApi* | [**CreatePortVlanAssignmentBatch**](docs/PortsApi.md#createportvlanassignmentbatch) | **Post** /ports/{id}/vlan-assignments/batches | Create a new Port-VLAN Assignment management batch
*PortsApi* | [**DeleteNativeVlan**](docs/PortsApi.md#deletenativevlan) | **Delete** /ports/{id}/native-vlan | Remove native VLAN
*PortsApi* | [**DisbondPort**](docs/PortsApi.md#disbondport) | **Post** /ports/{id}/disbond | Disabling bonding
*PortsApi* | [**FindPortById**](docs/PortsApi.md#findportbyid) | **Get** /ports/{id} | Retrieve a port
*PortsApi* | [**FindPortVlanAssignmentBatchByPortIdAndBatchId**](docs/PortsApi.md#findportvlanassignmentbatchbyportidandbatchid) | **Get** /ports/{id}/vlan-assignments/batches/{batch_id} | Retrieve a VLAN Assignment Batch&#39;s details
*PortsApi* | [**FindPortVlanAssignmentBatches**](docs/PortsApi.md#findportvlanassignmentbatches) | **Get** /ports/{id}/vlan-assignments/batches | List the VLAN Assignment Batches for a port
*PortsApi* | [**FindPortVlanAssignmentByPortIdAndAssignmentId**](docs/PortsApi.md#findportvlanassignmentbyportidandassignmentid) | **Get** /ports/{id}/vlan-assignments/{assignment_id} | Show a particular Port VLAN assignment&#39;s details
*PortsApi* | [**FindPortVlanAssignments**](docs/PortsApi.md#findportvlanassignments) | **Get** /ports/{id}/vlan-assignments | List Current VLAN assignments for a port
*PortsApi* | [**UnassignPort**](docs/PortsApi.md#unassignport) | **Post** /ports/{id}/unassign | Unassign a port
*ProjectsApi* | [**CreateProject**](docs/ProjectsApi.md#createproject) | **Post** /projects | Create a project
*ProjectsApi* | [**CreateProjectInvitation**](docs/ProjectsApi.md#createprojectinvitation) | **Post** /projects/{project_id}/invitations | Create an invitation for a project
*ProjectsApi* | [**CreateTransferRequest**](docs/ProjectsApi.md#createtransferrequest) | **Post** /projects/{id}/transfers | Create a transfer request
*ProjectsApi* | [**DeleteProject**](docs/ProjectsApi.md#deleteproject) | **Delete** /projects/{id} | Delete the project
*ProjectsApi* | [**FindIPReservationCustomdata**](docs/ProjectsApi.md#findipreservationcustomdata) | **Get** /projects/{project_id}/ips/{id}/customdata | Retrieve the custom metadata of an IP Reservation
*ProjectsApi* | [**FindProjectById**](docs/ProjectsApi.md#findprojectbyid) | **Get** /projects/{id} | Retrieve a project
*ProjectsApi* | [**FindProjectCustomdata**](docs/ProjectsApi.md#findprojectcustomdata) | **Get** /projects/{id}/customdata | Retrieve the custom metadata of a project
*ProjectsApi* | [**FindProjectInvitations**](docs/ProjectsApi.md#findprojectinvitations) | **Get** /projects/{project_id}/invitations | Retrieve project invitations
*ProjectsApi* | [**FindProjectMemberships**](docs/ProjectsApi.md#findprojectmemberships) | **Get** /projects/{project_id}/memberships | Retrieve project memberships
*ProjectsApi* | [**FindProjects**](docs/ProjectsApi.md#findprojects) | **Get** /projects | Retrieve all projects
*ProjectsApi* | [**UpdateProject**](docs/ProjectsApi.md#updateproject) | **Put** /projects/{id} | Update the project
*SSHKeysApi* | [**CreateProjectSSHKey**](docs/SSHKeysApi.md#createprojectsshkey) | **Post** /projects/{id}/ssh-keys | Create a ssh key for the given project
*SSHKeysApi* | [**CreateSSHKey**](docs/SSHKeysApi.md#createsshkey) | **Post** /ssh-keys | Create a ssh key for the current user
*SSHKeysApi* | [**DeleteSSHKey**](docs/SSHKeysApi.md#deletesshkey) | **Delete** /ssh-keys/{id} | Delete the ssh key
*SSHKeysApi* | [**FindDeviceSSHKeys**](docs/SSHKeysApi.md#finddevicesshkeys) | **Get** /devices/{id}/ssh-keys | Retrieve a device&#39;s ssh keys
*SSHKeysApi* | [**FindProjectSSHKeys**](docs/SSHKeysApi.md#findprojectsshkeys) | **Get** /projects/{id}/ssh-keys | Retrieve a project&#39;s ssh keys
*SSHKeysApi* | [**FindSSHKeyById**](docs/SSHKeysApi.md#findsshkeybyid) | **Get** /ssh-keys/{id} | Retrieve a ssh key
*SSHKeysApi* | [**FindSSHKeys**](docs/SSHKeysApi.md#findsshkeys) | **Get** /ssh-keys | Retrieve all ssh keys
*SSHKeysApi* | [**UpdateSSHKey**](docs/SSHKeysApi.md#updatesshkey) | **Put** /ssh-keys/{id} | Update the ssh key
*SelfServiceReservationsApi* | [**CreateSelfServiceReservation**](docs/SelfServiceReservationsApi.md#createselfservicereservation) | **Post** /projects/{project_id}/self-service/reservations | Create a reservation
*SelfServiceReservationsApi* | [**FindSelfServiceReservation**](docs/SelfServiceReservationsApi.md#findselfservicereservation) | **Get** /projects/{project_id}/self-service/reservations/{id} | Retrieve a reservation
*SelfServiceReservationsApi* | [**FindSelfServiceReservations**](docs/SelfServiceReservationsApi.md#findselfservicereservations) | **Get** /projects/{project_id}/self-service/reservations | Retrieve all reservations
*SpotMarketApi* | [**CreateSpotMarketRequest**](docs/SpotMarketApi.md#createspotmarketrequest) | **Post** /projects/{id}/spot-market-requests | Create a spot market request
*SpotMarketApi* | [**DeleteSpotMarketRequest**](docs/SpotMarketApi.md#deletespotmarketrequest) | **Delete** /spot-market-requests/{id} | Delete the spot market request
*SpotMarketApi* | [**FindMetroSpotMarketPrices**](docs/SpotMarketApi.md#findmetrospotmarketprices) | **Get** /market/spot/prices/metros | Get current spot market prices for metros
*SpotMarketApi* | [**FindSpotMarketPrices**](docs/SpotMarketApi.md#findspotmarketprices) | **Get** /market/spot/prices | Get current spot market prices
*SpotMarketApi* | [**FindSpotMarketPricesHistory**](docs/SpotMarketApi.md#findspotmarketpriceshistory) | **Get** /market/spot/prices/history | Get spot market prices for a given period of time
*SpotMarketApi* | [**FindSpotMarketRequestById**](docs/SpotMarketApi.md#findspotmarketrequestbyid) | **Get** /spot-market-requests/{id} | Retrieve a spot market request
*SpotMarketApi* | [**ListSpotMarketRequests**](docs/SpotMarketApi.md#listspotmarketrequests) | **Get** /projects/{id}/spot-market-requests | List spot market requests
*SupportRequestApi* | [**RequestSupport**](docs/SupportRequestApi.md#requestsupport) | **Post** /support-requests | Create a support ticket
*TransferRequestsApi* | [**AcceptTransferRequest**](docs/TransferRequestsApi.md#accepttransferrequest) | **Put** /transfers/{id} | Accept a transfer request
*TransferRequestsApi* | [**DeclineTransferRequest**](docs/TransferRequestsApi.md#declinetransferrequest) | **Delete** /transfers/{id} | Decline a transfer request
*TransferRequestsApi* | [**FindTransferRequestById**](docs/TransferRequestsApi.md#findtransferrequestbyid) | **Get** /transfers/{id} | View a transfer request
*TwoFactorAuthApi* | [**DisableTfaApp**](docs/TwoFactorAuthApi.md#disabletfaapp) | **Delete** /user/otp/app | Disable two factor authentication
*TwoFactorAuthApi* | [**DisableTfaSms**](docs/TwoFactorAuthApi.md#disabletfasms) | **Delete** /user/otp/sms | Disable two factor authentication
*TwoFactorAuthApi* | [**EnableTfaApp**](docs/TwoFactorAuthApi.md#enabletfaapp) | **Post** /user/otp/app | Enable two factor auth using app
*TwoFactorAuthApi* | [**EnableTfaSms**](docs/TwoFactorAuthApi.md#enabletfasms) | **Post** /user/otp/sms | Enable two factor auth using sms
*UsagesApi* | [**FindDeviceUsages**](docs/UsagesApi.md#finddeviceusages) | **Get** /devices/{id}/usages | Retrieve all usages for device
*UsagesApi* | [**FindProjectUsage**](docs/UsagesApi.md#findprojectusage) | **Get** /projects/{id}/usages | Retrieve all usages for project
*UserVerificationTokensApi* | [**ConsumeVerificationRequest**](docs/UserVerificationTokensApi.md#consumeverificationrequest) | **Put** /verify-email | Verify a user using an email verification token
*UserVerificationTokensApi* | [**CreateValidationRequest**](docs/UserVerificationTokensApi.md#createvalidationrequest) | **Post** /verify-email | Create an email verification request
*UserdataApi* | [**ValidateUserdata**](docs/UserdataApi.md#validateuserdata) | **Post** /userdata/validate | Validate user data
*UsersApi* | [**CreateUser**](docs/UsersApi.md#createuser) | **Post** /users | Create a user
*UsersApi* | [**FindCurrentUser**](docs/UsersApi.md#findcurrentuser) | **Get** /user | Retrieve the current user
*UsersApi* | [**FindInvitations**](docs/UsersApi.md#findinvitations) | **Get** /invitations | Retrieve current user invitations
*UsersApi* | [**FindUserById**](docs/UsersApi.md#finduserbyid) | **Get** /users/{id} | Retrieve a user
*UsersApi* | [**FindUserCustomdata**](docs/UsersApi.md#findusercustomdata) | **Get** /users/{id}/customdata | Retrieve the custom metadata of a user
*UsersApi* | [**FindUsers**](docs/UsersApi.md#findusers) | **Get** /users | Retrieve all users
*UsersApi* | [**UpdateCurrentUser**](docs/UsersApi.md#updatecurrentuser) | **Put** /user | Update the current user
*VLANsApi* | [**CreateVirtualNetwork**](docs/VLANsApi.md#createvirtualnetwork) | **Post** /projects/{id}/virtual-networks | Create a virtual network
*VLANsApi* | [**DeleteVirtualNetwork**](docs/VLANsApi.md#deletevirtualnetwork) | **Delete** /virtual-networks/{id} | Delete a virtual network
*VLANsApi* | [**FindVirtualNetworks**](docs/VLANsApi.md#findvirtualnetworks) | **Get** /projects/{id}/virtual-networks | Retrieve all virtual networks
*VLANsApi* | [**GetVirtualNetwork**](docs/VLANsApi.md#getvirtualnetwork) | **Get** /virtual-networks/{id} | Get a virtual network
*VLANsApi* | [**UpdateVirtualNetwork**](docs/VLANsApi.md#updatevirtualnetwork) | **Put** /virtual-networks/{id} | Updates the virtual network
*VRFsApi* | [**BgpDynamicNeighborsIdGet**](docs/VRFsApi.md#bgpdynamicneighborsidget) | **Get** /bgp-dynamic-neighbors/{id} | Retrieve a BGP Dynamic Neighbor
*VRFsApi* | [**CreateBgpDynamicNeighbor**](docs/VRFsApi.md#createbgpdynamicneighbor) | **Post** /metal-gateways/{id}/bgp-dynamic-neighbors | Create a VRF BGP Dynamic Neighbor range
*VRFsApi* | [**CreateVrf**](docs/VRFsApi.md#createvrf) | **Post** /projects/{id}/vrfs | Create a new VRF in the specified project
*VRFsApi* | [**CreateVrfRoute**](docs/VRFsApi.md#createvrfroute) | **Post** /vrfs/{id}/routes | Create a VRF route
*VRFsApi* | [**DeleteBgpDynamicNeighborById**](docs/VRFsApi.md#deletebgpdynamicneighborbyid) | **Delete** /bgp-dynamic-neighbors/{id} | Delete a VRF BGP Dynamic Neighbor
*VRFsApi* | [**DeleteVrf**](docs/VRFsApi.md#deletevrf) | **Delete** /vrfs/{id} | Delete the VRF
*VRFsApi* | [**DeleteVrfRouteById**](docs/VRFsApi.md#deletevrfroutebyid) | **Delete** /routes/{id} | Delete a VRF Route
*VRFsApi* | [**FindVrfById**](docs/VRFsApi.md#findvrfbyid) | **Get** /vrfs/{id} | Retrieve a VRF
*VRFsApi* | [**FindVrfIpReservation**](docs/VRFsApi.md#findvrfipreservation) | **Get** /vrfs/{vrf_id}/ips/{id} | Retrieve the Specified VRF IP Reservation
*VRFsApi* | [**FindVrfIpReservations**](docs/VRFsApi.md#findvrfipreservations) | **Get** /vrfs/{id}/ips | Retrieve all VRF IP Reservations in the VRF
*VRFsApi* | [**FindVrfRouteById**](docs/VRFsApi.md#findvrfroutebyid) | **Get** /routes/{id} | Retrieve a VRF Route
*VRFsApi* | [**FindVrfs**](docs/VRFsApi.md#findvrfs) | **Get** /projects/{id}/vrfs | Retrieve all VRFs in the project
*VRFsApi* | [**GetBgpDynamicNeighbors**](docs/VRFsApi.md#getbgpdynamicneighbors) | **Get** /metal-gateways/{id}/bgp-dynamic-neighbors | List BGP Dynamic Neighbors
*VRFsApi* | [**GetVrfBGPNeighbors**](docs/VRFsApi.md#getvrfbgpneighbors) | **Get** /vrfs/{id}/bgp-neighbors | Retrieve BGP neighbor states for the VRF
*VRFsApi* | [**GetVrfLearnedRoutes**](docs/VRFsApi.md#getvrflearnedroutes) | **Get** /vrfs/{id}/learned-routes | Retrieve learned L3 routes within the VRF
*VRFsApi* | [**GetVrfRoutes**](docs/VRFsApi.md#getvrfroutes) | **Get** /vrfs/{id}/routes | Retrieve all routes in the VRF
*VRFsApi* | [**UpdateVrf**](docs/VRFsApi.md#updatevrf) | **Put** /vrfs/{id} | Update the VRF
*VRFsApi* | [**UpdateVrfRouteById**](docs/VRFsApi.md#updatevrfroutebyid) | **Put** /routes/{id} | Update a VRF Route


## Documentation For Models

 - [AWSFabricProvider](docs/AWSFabricProvider.md)
 - [AWSFabricProviderType](docs/AWSFabricProviderType.md)
 - [ActivateHardwareReservationRequest](docs/ActivateHardwareReservationRequest.md)
 - [Address](docs/Address.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeData](docs/AttributeData.md)
 - [AuthToken](docs/AuthToken.md)
 - [AuthTokenInput](docs/AuthTokenInput.md)
 - [AuthTokenList](docs/AuthTokenList.md)
 - [AuthTokenProject](docs/AuthTokenProject.md)
 - [AuthTokenUser](docs/AuthTokenUser.md)
 - [BGPSessionInput](docs/BGPSessionInput.md)
 - [BGPSessionInputAddressFamily](docs/BGPSessionInputAddressFamily.md)
 - [Batch](docs/Batch.md)
 - [BatchesList](docs/BatchesList.md)
 - [BgpConfig](docs/BgpConfig.md)
 - [BgpConfigDeploymentType](docs/BgpConfigDeploymentType.md)
 - [BgpConfigRequestInput](docs/BgpConfigRequestInput.md)
 - [BgpConfigRequestInputDeploymentType](docs/BgpConfigRequestInputDeploymentType.md)
 - [BgpConfigStatus](docs/BgpConfigStatus.md)
 - [BgpDynamicNeighbor](docs/BgpDynamicNeighbor.md)
 - [BgpDynamicNeighborCreateInput](docs/BgpDynamicNeighborCreateInput.md)
 - [BgpDynamicNeighborList](docs/BgpDynamicNeighborList.md)
 - [BgpDynamicNeighborState](docs/BgpDynamicNeighborState.md)
 - [BgpNeighborData](docs/BgpNeighborData.md)
 - [BgpRoute](docs/BgpRoute.md)
 - [BgpSession](docs/BgpSession.md)
 - [BgpSessionAddressFamily](docs/BgpSessionAddressFamily.md)
 - [BgpSessionList](docs/BgpSessionList.md)
 - [BgpSessionNeighbors](docs/BgpSessionNeighbors.md)
 - [BondPortData](docs/BondPortData.md)
 - [CapacityCheckPerFacilityInfo](docs/CapacityCheckPerFacilityInfo.md)
 - [CapacityCheckPerFacilityList](docs/CapacityCheckPerFacilityList.md)
 - [CapacityCheckPerMetroInfo](docs/CapacityCheckPerMetroInfo.md)
 - [CapacityCheckPerMetroList](docs/CapacityCheckPerMetroList.md)
 - [CapacityInput](docs/CapacityInput.md)
 - [CapacityLevelPerBaremetal](docs/CapacityLevelPerBaremetal.md)
 - [CapacityList](docs/CapacityList.md)
 - [Component](docs/Component.md)
 - [Coordinates](docs/Coordinates.md)
 - [CreateDeviceRequest](docs/CreateDeviceRequest.md)
 - [CreateEmailInput](docs/CreateEmailInput.md)
 - [CreateMetalGatewayRequest](docs/CreateMetalGatewayRequest.md)
 - [CreateOrganizationInterconnectionRequest](docs/CreateOrganizationInterconnectionRequest.md)
 - [CreateSelfServiceReservationRequest](docs/CreateSelfServiceReservationRequest.md)
 - [CreateSelfServiceReservationRequestPeriod](docs/CreateSelfServiceReservationRequestPeriod.md)
 - [CreateSelfServiceReservationRequestPeriodCount](docs/CreateSelfServiceReservationRequestPeriodCount.md)
 - [CreateSelfServiceReservationRequestPeriodUnit](docs/CreateSelfServiceReservationRequestPeriodUnit.md)
 - [DedicatedPortCreateInput](docs/DedicatedPortCreateInput.md)
 - [DedicatedPortCreateInputMode](docs/DedicatedPortCreateInputMode.md)
 - [DedicatedPortCreateInputType](docs/DedicatedPortCreateInputType.md)
 - [Device](docs/Device.md)
 - [DeviceActionInput](docs/DeviceActionInput.md)
 - [DeviceActionInputType](docs/DeviceActionInputType.md)
 - [DeviceActionsInner](docs/DeviceActionsInner.md)
 - [DeviceCreateInFacilityInput](docs/DeviceCreateInFacilityInput.md)
 - [DeviceCreateInMetroInput](docs/DeviceCreateInMetroInput.md)
 - [DeviceCreateInput](docs/DeviceCreateInput.md)
 - [DeviceCreateInputBillingCycle](docs/DeviceCreateInputBillingCycle.md)
 - [DeviceCreatedBy](docs/DeviceCreatedBy.md)
 - [DeviceHealthRollup](docs/DeviceHealthRollup.md)
 - [DeviceHealthRollupHealthRollup](docs/DeviceHealthRollupHealthRollup.md)
 - [DeviceList](docs/DeviceList.md)
 - [DeviceMetro](docs/DeviceMetro.md)
 - [DeviceProjectLite](docs/DeviceProjectLite.md)
 - [DeviceState](docs/DeviceState.md)
 - [DeviceUpdateInput](docs/DeviceUpdateInput.md)
 - [DeviceUsage](docs/DeviceUsage.md)
 - [DeviceUsageList](docs/DeviceUsageList.md)
 - [Disk](docs/Disk.md)
 - [Email](docs/Email.md)
 - [EmailInput](docs/EmailInput.md)
 - [Entitlement](docs/Entitlement.md)
 - [Error](docs/Error.md)
 - [Event](docs/Event.md)
 - [EventList](docs/EventList.md)
 - [FabricServiceToken](docs/FabricServiceToken.md)
 - [FabricServiceTokenRole](docs/FabricServiceTokenRole.md)
 - [FabricServiceTokenServiceTokenType](docs/FabricServiceTokenServiceTokenType.md)
 - [FabricServiceTokenState](docs/FabricServiceTokenState.md)
 - [Facility](docs/Facility.md)
 - [FacilityFeaturesInner](docs/FacilityFeaturesInner.md)
 - [FacilityInput](docs/FacilityInput.md)
 - [FacilityList](docs/FacilityList.md)
 - [Filesystem](docs/Filesystem.md)
 - [FindFacilitiesIncludeParameterInner](docs/FindFacilitiesIncludeParameterInner.md)
 - [FindIPAddressById200Response](docs/FindIPAddressById200Response.md)
 - [FindIPAvailabilitiesCidrParameter](docs/FindIPAvailabilitiesCidrParameter.md)
 - [FindIPReservationsTypesParameterInner](docs/FindIPReservationsTypesParameterInner.md)
 - [FindMetalGatewayById200Response](docs/FindMetalGatewayById200Response.md)
 - [FindOrganizationDevicesCategoriesParameterInner](docs/FindOrganizationDevicesCategoriesParameterInner.md)
 - [FindOrganizationsPersonalParameter](docs/FindOrganizationsPersonalParameter.md)
 - [FindPlansTypeParameter](docs/FindPlansTypeParameter.md)
 - [FindProjectHardwareReservationsProvisionableParameter](docs/FindProjectHardwareReservationsProvisionableParameter.md)
 - [FindProjectHardwareReservationsStateParameter](docs/FindProjectHardwareReservationsStateParameter.md)
 - [FindTrafficBucketParameter](docs/FindTrafficBucketParameter.md)
 - [FindTrafficDirectionParameter](docs/FindTrafficDirectionParameter.md)
 - [FindTrafficIntervalParameter](docs/FindTrafficIntervalParameter.md)
 - [FindTrafficTimeframeParameter](docs/FindTrafficTimeframeParameter.md)
 - [FirmwareSet](docs/FirmwareSet.md)
 - [FirmwareSetListResponse](docs/FirmwareSetListResponse.md)
 - [FirmwareSetResponse](docs/FirmwareSetResponse.md)
 - [GlobalBgpRange](docs/GlobalBgpRange.md)
 - [GlobalBgpRangeList](docs/GlobalBgpRangeList.md)
 - [HardwareReservation](docs/HardwareReservation.md)
 - [HardwareReservationList](docs/HardwareReservationList.md)
 - [Href](docs/Href.md)
 - [IPAddress](docs/IPAddress.md)
 - [IPAddressAddressFamily](docs/IPAddressAddressFamily.md)
 - [IPAssignment](docs/IPAssignment.md)
 - [IPAssignmentInput](docs/IPAssignmentInput.md)
 - [IPAssignmentList](docs/IPAssignmentList.md)
 - [IPAssignmentMetro](docs/IPAssignmentMetro.md)
 - [IPAssignmentState](docs/IPAssignmentState.md)
 - [IPAssignmentType](docs/IPAssignmentType.md)
 - [IPAssignmentUpdateInput](docs/IPAssignmentUpdateInput.md)
 - [IPAvailabilitiesList](docs/IPAvailabilitiesList.md)
 - [IPReservation](docs/IPReservation.md)
 - [IPReservationFacility](docs/IPReservationFacility.md)
 - [IPReservationList](docs/IPReservationList.md)
 - [IPReservationListIpAddressesInner](docs/IPReservationListIpAddressesInner.md)
 - [IPReservationMetro](docs/IPReservationMetro.md)
 - [IPReservationRequestInput](docs/IPReservationRequestInput.md)
 - [IPReservationType](docs/IPReservationType.md)
 - [InstancesBatchCreateInput](docs/InstancesBatchCreateInput.md)
 - [InstancesBatchCreateInputBatchesInner](docs/InstancesBatchCreateInputBatchesInner.md)
 - [Interconnection](docs/Interconnection.md)
 - [InterconnectionFabricProvider](docs/InterconnectionFabricProvider.md)
 - [InterconnectionList](docs/InterconnectionList.md)
 - [InterconnectionMetroList](docs/InterconnectionMetroList.md)
 - [InterconnectionMetroListMetrosInner](docs/InterconnectionMetroListMetrosInner.md)
 - [InterconnectionMetroListMetrosInnerAllOfProvidersInner](docs/InterconnectionMetroListMetrosInnerAllOfProvidersInner.md)
 - [InterconnectionMode](docs/InterconnectionMode.md)
 - [InterconnectionPort](docs/InterconnectionPort.md)
 - [InterconnectionPortList](docs/InterconnectionPortList.md)
 - [InterconnectionPortRole](docs/InterconnectionPortRole.md)
 - [InterconnectionPortStatus](docs/InterconnectionPortStatus.md)
 - [InterconnectionPricingList](docs/InterconnectionPricingList.md)
 - [InterconnectionPricingListProviderPricingInner](docs/InterconnectionPricingListProviderPricingInner.md)
 - [InterconnectionPricingListProviderPricingInnerTiersInner](docs/InterconnectionPricingListProviderPricingInnerTiersInner.md)
 - [InterconnectionRedundancy](docs/InterconnectionRedundancy.md)
 - [InterconnectionType](docs/InterconnectionType.md)
 - [InterconnectionUpdateInput](docs/InterconnectionUpdateInput.md)
 - [Invitation](docs/Invitation.md)
 - [InvitationInput](docs/InvitationInput.md)
 - [InvitationList](docs/InvitationList.md)
 - [InvitationRolesInner](docs/InvitationRolesInner.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceList](docs/InvoiceList.md)
 - [License](docs/License.md)
 - [LicenseCreateInput](docs/LicenseCreateInput.md)
 - [LicenseList](docs/LicenseList.md)
 - [LicenseUpdateInput](docs/LicenseUpdateInput.md)
 - [LineItem](docs/LineItem.md)
 - [LineItemAdjustment](docs/LineItemAdjustment.md)
 - [Membership](docs/Membership.md)
 - [MembershipInput](docs/MembershipInput.md)
 - [MembershipList](docs/MembershipList.md)
 - [Meta](docs/Meta.md)
 - [Metadata](docs/Metadata.md)
 - [MetadataNetwork](docs/MetadataNetwork.md)
 - [MetadataNetworkNetwork](docs/MetadataNetworkNetwork.md)
 - [MetadataNetworkNetworkBonding](docs/MetadataNetworkNetworkBonding.md)
 - [MetalGateway](docs/MetalGateway.md)
 - [MetalGatewayCreateInput](docs/MetalGatewayCreateInput.md)
 - [MetalGatewayElasticIpCreateInput](docs/MetalGatewayElasticIpCreateInput.md)
 - [MetalGatewayList](docs/MetalGatewayList.md)
 - [MetalGatewayListMetalGatewaysInner](docs/MetalGatewayListMetalGatewaysInner.md)
 - [MetalGatewayLite](docs/MetalGatewayLite.md)
 - [MetalGatewayState](docs/MetalGatewayState.md)
 - [Metro](docs/Metro.md)
 - [MetroInput](docs/MetroInput.md)
 - [MetroList](docs/MetroList.md)
 - [Mount](docs/Mount.md)
 - [MoveHardwareReservationRequest](docs/MoveHardwareReservationRequest.md)
 - [NewPassword](docs/NewPassword.md)
 - [OperatingSystem](docs/OperatingSystem.md)
 - [OperatingSystemList](docs/OperatingSystemList.md)
 - [Organization](docs/Organization.md)
 - [OrganizationInput](docs/OrganizationInput.md)
 - [OrganizationList](docs/OrganizationList.md)
 - [OtpSeed](docs/OtpSeed.md)
 - [ParentBlock](docs/ParentBlock.md)
 - [Partition](docs/Partition.md)
 - [PaymentMethod](docs/PaymentMethod.md)
 - [PaymentMethodBillingAddress](docs/PaymentMethodBillingAddress.md)
 - [PaymentMethodCreateInput](docs/PaymentMethodCreateInput.md)
 - [PaymentMethodList](docs/PaymentMethodList.md)
 - [PaymentMethodUpdateInput](docs/PaymentMethodUpdateInput.md)
 - [Plan](docs/Plan.md)
 - [PlanAvailableInInner](docs/PlanAvailableInInner.md)
 - [PlanAvailableInInnerPrice](docs/PlanAvailableInInnerPrice.md)
 - [PlanAvailableInMetrosInner](docs/PlanAvailableInMetrosInner.md)
 - [PlanDeploymentTypesInner](docs/PlanDeploymentTypesInner.md)
 - [PlanIdName](docs/PlanIdName.md)
 - [PlanList](docs/PlanList.md)
 - [PlanSpecs](docs/PlanSpecs.md)
 - [PlanSpecsCpusInner](docs/PlanSpecsCpusInner.md)
 - [PlanSpecsDrivesInner](docs/PlanSpecsDrivesInner.md)
 - [PlanSpecsFeatures](docs/PlanSpecsFeatures.md)
 - [PlanSpecsMemory](docs/PlanSpecsMemory.md)
 - [PlanSpecsNicsInner](docs/PlanSpecsNicsInner.md)
 - [PlanType](docs/PlanType.md)
 - [Port](docs/Port.md)
 - [PortAssignInput](docs/PortAssignInput.md)
 - [PortConvertLayer3Input](docs/PortConvertLayer3Input.md)
 - [PortConvertLayer3InputRequestIpsInner](docs/PortConvertLayer3InputRequestIpsInner.md)
 - [PortData](docs/PortData.md)
 - [PortNetworkType](docs/PortNetworkType.md)
 - [PortType](docs/PortType.md)
 - [PortVlanAssignment](docs/PortVlanAssignment.md)
 - [PortVlanAssignmentBatch](docs/PortVlanAssignmentBatch.md)
 - [PortVlanAssignmentBatchCreateInput](docs/PortVlanAssignmentBatchCreateInput.md)
 - [PortVlanAssignmentBatchCreateInputVlanAssignmentsInner](docs/PortVlanAssignmentBatchCreateInputVlanAssignmentsInner.md)
 - [PortVlanAssignmentBatchList](docs/PortVlanAssignmentBatchList.md)
 - [PortVlanAssignmentBatchState](docs/PortVlanAssignmentBatchState.md)
 - [PortVlanAssignmentBatchVlanAssignmentsInner](docs/PortVlanAssignmentBatchVlanAssignmentsInner.md)
 - [PortVlanAssignmentBatchVlanAssignmentsInnerState](docs/PortVlanAssignmentBatchVlanAssignmentsInnerState.md)
 - [PortVlanAssignmentList](docs/PortVlanAssignmentList.md)
 - [PortVlanAssignmentState](docs/PortVlanAssignmentState.md)
 - [Project](docs/Project.md)
 - [ProjectCreateFromRootInput](docs/ProjectCreateFromRootInput.md)
 - [ProjectCreateFromRootInputType](docs/ProjectCreateFromRootInputType.md)
 - [ProjectCreateInput](docs/ProjectCreateInput.md)
 - [ProjectIdName](docs/ProjectIdName.md)
 - [ProjectList](docs/ProjectList.md)
 - [ProjectType](docs/ProjectType.md)
 - [ProjectUpdateInput](docs/ProjectUpdateInput.md)
 - [ProjectUsage](docs/ProjectUsage.md)
 - [ProjectUsageList](docs/ProjectUsageList.md)
 - [Raid](docs/Raid.md)
 - [RecoveryCodeList](docs/RecoveryCodeList.md)
 - [RequestIPReservation201Response](docs/RequestIPReservation201Response.md)
 - [RequestIPReservationRequest](docs/RequestIPReservationRequest.md)
 - [SSHKey](docs/SSHKey.md)
 - [SSHKeyCreateInput](docs/SSHKeyCreateInput.md)
 - [SSHKeyInput](docs/SSHKeyInput.md)
 - [SSHKeyList](docs/SSHKeyList.md)
 - [SelfServiceReservationItemRequest](docs/SelfServiceReservationItemRequest.md)
 - [SelfServiceReservationItemResponse](docs/SelfServiceReservationItemResponse.md)
 - [SelfServiceReservationList](docs/SelfServiceReservationList.md)
 - [SelfServiceReservationResponse](docs/SelfServiceReservationResponse.md)
 - [ServerInfo](docs/ServerInfo.md)
 - [SharedPortVCVlanCreateInput](docs/SharedPortVCVlanCreateInput.md)
 - [SharedPortVCVlanCreateInputType](docs/SharedPortVCVlanCreateInputType.md)
 - [SpotMarketPricesList](docs/SpotMarketPricesList.md)
 - [SpotMarketPricesPerMetroList](docs/SpotMarketPricesPerMetroList.md)
 - [SpotMarketPricesPerMetroReport](docs/SpotMarketPricesPerMetroReport.md)
 - [SpotMarketRequest](docs/SpotMarketRequest.md)
 - [SpotMarketRequestCreateInput](docs/SpotMarketRequestCreateInput.md)
 - [SpotMarketRequestCreateInputInstanceParameters](docs/SpotMarketRequestCreateInputInstanceParameters.md)
 - [SpotMarketRequestList](docs/SpotMarketRequestList.md)
 - [SpotMarketRequestMetro](docs/SpotMarketRequestMetro.md)
 - [SpotPricesDatapoints](docs/SpotPricesDatapoints.md)
 - [SpotPricesHistoryReport](docs/SpotPricesHistoryReport.md)
 - [SpotPricesPerBaremetal](docs/SpotPricesPerBaremetal.md)
 - [SpotPricesPerFacility](docs/SpotPricesPerFacility.md)
 - [SpotPricesPerNewFacility](docs/SpotPricesPerNewFacility.md)
 - [SpotPricesReport](docs/SpotPricesReport.md)
 - [Storage](docs/Storage.md)
 - [SupportRequestInput](docs/SupportRequestInput.md)
 - [SupportRequestInputPriority](docs/SupportRequestInputPriority.md)
 - [TransferRequest](docs/TransferRequest.md)
 - [TransferRequestInput](docs/TransferRequestInput.md)
 - [TransferRequestList](docs/TransferRequestList.md)
 - [UpdateEmailInput](docs/UpdateEmailInput.md)
 - [User](docs/User.md)
 - [UserCreateInput](docs/UserCreateInput.md)
 - [UserLimited](docs/UserLimited.md)
 - [UserList](docs/UserList.md)
 - [UserLite](docs/UserLite.md)
 - [UserUpdateInput](docs/UserUpdateInput.md)
 - [Userdata](docs/Userdata.md)
 - [VerifyEmail](docs/VerifyEmail.md)
 - [VirtualCircuit](docs/VirtualCircuit.md)
 - [VirtualCircuitCreateInput](docs/VirtualCircuitCreateInput.md)
 - [VirtualCircuitList](docs/VirtualCircuitList.md)
 - [VirtualCircuitUpdateInput](docs/VirtualCircuitUpdateInput.md)
 - [VirtualNetwork](docs/VirtualNetwork.md)
 - [VirtualNetworkCreateInput](docs/VirtualNetworkCreateInput.md)
 - [VirtualNetworkList](docs/VirtualNetworkList.md)
 - [VirtualNetworkUpdateInput](docs/VirtualNetworkUpdateInput.md)
 - [VlanCSPConnectionCreateInput](docs/VlanCSPConnectionCreateInput.md)
 - [VlanCSPConnectionCreateInputFabricProvider](docs/VlanCSPConnectionCreateInputFabricProvider.md)
 - [VlanCSPConnectionCreateInputType](docs/VlanCSPConnectionCreateInputType.md)
 - [VlanFabricVcCreateInput](docs/VlanFabricVcCreateInput.md)
 - [VlanFabricVcCreateInputServiceTokenType](docs/VlanFabricVcCreateInputServiceTokenType.md)
 - [VlanFabricVcCreateInputType](docs/VlanFabricVcCreateInputType.md)
 - [VlanVirtualCircuit](docs/VlanVirtualCircuit.md)
 - [VlanVirtualCircuitBillType](docs/VlanVirtualCircuitBillType.md)
 - [VlanVirtualCircuitCreateInput](docs/VlanVirtualCircuitCreateInput.md)
 - [VlanVirtualCircuitStatus](docs/VlanVirtualCircuitStatus.md)
 - [VlanVirtualCircuitType](docs/VlanVirtualCircuitType.md)
 - [VlanVirtualCircuitUpdateInput](docs/VlanVirtualCircuitUpdateInput.md)
 - [Vrf](docs/Vrf.md)
 - [VrfBGPNeighbors](docs/VrfBGPNeighbors.md)
 - [VrfBGPNeighborsList](docs/VrfBGPNeighborsList.md)
 - [VrfCreateInput](docs/VrfCreateInput.md)
 - [VrfFabricVcCreateInput](docs/VrfFabricVcCreateInput.md)
 - [VrfIpReservation](docs/VrfIpReservation.md)
 - [VrfIpReservationCreateInput](docs/VrfIpReservationCreateInput.md)
 - [VrfIpReservationList](docs/VrfIpReservationList.md)
 - [VrfIpReservationType](docs/VrfIpReservationType.md)
 - [VrfLearnedRoutes](docs/VrfLearnedRoutes.md)
 - [VrfLearnedRoutesList](docs/VrfLearnedRoutesList.md)
 - [VrfList](docs/VrfList.md)
 - [VrfMetalGateway](docs/VrfMetalGateway.md)
 - [VrfMetalGatewayCreateInput](docs/VrfMetalGatewayCreateInput.md)
 - [VrfRoute](docs/VrfRoute.md)
 - [VrfRouteCreateInput](docs/VrfRouteCreateInput.md)
 - [VrfRouteList](docs/VrfRouteList.md)
 - [VrfRouteStatus](docs/VrfRouteStatus.md)
 - [VrfRouteType](docs/VrfRouteType.md)
 - [VrfRouteUpdateInput](docs/VrfRouteUpdateInput.md)
 - [VrfUpdateInput](docs/VrfUpdateInput.md)
 - [VrfVirtualCircuit](docs/VrfVirtualCircuit.md)
 - [VrfVirtualCircuitCreateInput](docs/VrfVirtualCircuitCreateInput.md)
 - [VrfVirtualCircuitStatus](docs/VrfVirtualCircuitStatus.md)
 - [VrfVirtualCircuitUpdateInput](docs/VrfVirtualCircuitUpdateInput.md)


## Documentation For Authorization


Authentication schemes defined for the API:
### x_auth_token

- **Type**: API key
- **API key parameter name**: X-Auth-Token
- **Location**: HTTP header

Note, each API key must be added to a map of `map[string]APIKey` where the key is: X-Auth-Token and passed in as the auth context for each request.

Example

```go
auth := context.WithValue(
		context.Background(),
		metalv1.ContextAPIKeys,
		map[string]metalv1.APIKey{
			"X-Auth-Token": {Key: "API_KEY_STRING"},
		},
	)
r, err := client.Service.Operation(auth, args)
```


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author

support@equinixmetal.com

